/***********************************************************************
 *                copyright 2001, Amoco Production Company             *
 *                            All Rights Reserved                      *
 *                    an affiliate of BP America Inc.                  *
 ***********************************************************************/
/*
**	the system-dependent entry to return the number of
**	command-line arguments
*/
/*
        changed long declarations to int; these are NOT the same!
                                                - joe m. wade 5/26/95
*/
#include <localsys.h>
#include <fu_defs.h>

void F_U0ARGCC( n )
int *n;
{
#if defined( SUNSYSTEM ) || defined( CONVEXSYSTEM ) || defined( LINUXSYSTEM ) || defined( DECSYSTEM ) || defined ( APPLESYSTEM )

	int iargc_();

	*n = iargc_() + 1;
	return;
#else
#ifdef CRAYSYSTEM
	extern int _argc;
	*n = _argc;
	return;
#else
#ifdef HPUXSYSTEM
	int IARGC();

	*n = IARGC() + 1;
	return;
#else
#ifdef AIXSYSTEM
	int iargc();

	*n = iargc() + 1;
	return;
#else
#ifdef SGISYSTEM
	int iargc_();

	*n = iargc_() + 1;
	return;
#else
	system_unrecognized - kill the compiler -
#endif
#endif
#endif
#endif
#endif
}
